# partector2

This package works with the namespace naneos. The structure in the src folder is applied to obtain this result.


## Description

A longer description of your project goes here...


<!-- pyscaffold-notes -->

## Note

This project has been set up using PyScaffold 4.2.1. For details and usage
information on PyScaffold see https://pyscaffold.org/.
